@@ -13,20 +13,13 @@ gi.require_version("Gtk", "3.0")
 # internal modules
 import thunar_plugins.version
 import thunar_plugins.l10n
+import thunar_plugins.log
 import thunar_plugins.menus
 import thunar_plugins.config
 
-# external modules
 
 THUNAR_PLUGIN_ENTRY_POINT_NAME = "thunar_plugin"
 
-
-logging.basicConfig(
-    level=logging.DEBUG
-    if os.environ.get("THUNAR_PLUGINS_DEBUG")
-    else logging.WARNING
-)
-
 logger = logging.getLogger(__name__)
 
 
