@@ -9,6 +9,14 @@ import rich
 from rich.logging import RichHandler
 from rich.console import Console
 
+import gi
+
+gi.require_version("Notify", "0.7")
+
+from gi.repository import Notify
+
+Notify.init("thunar-plugins Python package")
+
 loglevel = (
     os.environ.get("THUNAR_PLUGINS_LOGLEVEL", "warning").upper() or "WARNING"
 )
