@@ -21,9 +21,6 @@ def call_if_possible(x):
 
 
 class PluginPreferences(GObject.GObject, Thunarx.PreferencesProvider):
-    def __init__(self):
-        logger.debug(self.__init__)
-
     @property
     def config(self):
         try:
